import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _extends from 'babel-runtime/helpers/extends';
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import cx from 'classnames';
import Pane from './Pane';
import theme from './theme';
import SuccessAlertIcon from './SuccessAlertIcon';
import QuestionAlertIcon from './QuestionAlertIcon';
import DangerAlertIcon from './DangerAlertIcon';
import WarningAlertIcon from './WarningAlertIcon';
var minorScale = theme.minorScale,
    majorScale = theme.majorScale;


var getStyle = function getStyle(_ref) {
  var type = _ref.type,
      showTrim = _ref.showTrim;

  var trim = showTrim ? {
    '&:before': {
      content: '""',
      width: minorScale(1),
      height: '100%',
      position: 'absolute',
      top: 0,
      left: 0,
      backgroundColor: theme.colors[type]
    }
  } : {};

  return css(_extends({
    'boxShadow': '' + theme.shadows[0]
  }, trim));
};

var parseProps = function parseProps(_ref2) {
  var className = _ref2.className,
      type = _ref2.type,
      showTrim = _ref2.showTrim,
      props = _objectWithoutProperties(_ref2, ['className', 'type', 'showTrim']);

  return _extends({
    className: cx('' + getStyle({ type: type, showTrim: showTrim }), className)
  }, props);
};

var AlertIcon = function AlertIcon(_ref3) {
  var type = _ref3.type,
      props = _objectWithoutProperties(_ref3, ['type']);

  switch (type) {
    case 'success':
      return React.createElement(SuccessAlertIcon, props);
    case 'question':
      return React.createElement(QuestionAlertIcon, props);
    case 'warning':
      return React.createElement(WarningAlertIcon, props);
    case 'danger':
      return React.createElement(DangerAlertIcon, props);
    default:
      return null;
  }
};

AlertIcon.propTypes = _extends({}, SuccessAlertIcon.propTypes);

AlertIcon.defaultProps = {
  marginTop: minorScale(1),
  marginRight: majorScale(2)
};

var Alert = function Alert(_ref4) {
  var children = _ref4.children,
      showIcon = _ref4.showIcon,
      props = _objectWithoutProperties(_ref4, ['children', 'showIcon']);

  return React.createElement(
    Pane,
    parseProps(props),
    showIcon && React.createElement(AlertIcon, { flexShrink: '0', type: props.type }),
    React.createElement(
      Pane,
      null,
      children
    )
  );
};

Alert.propTypes = _extends({}, Pane.propTypes, {
  type: PropTypes.oneOf(['naked', 'success', 'warning', 'danger', 'question']),
  showIcon: PropTypes.bool,
  showTrim: PropTypes.bool
});

Alert.defaultProps = {
  showIcon: true,
  showTrim: true,
  type: 'naked',
  white: true,
  rounded: true,
  paddingX: majorScale(3),
  paddingY: majorScale(2),
  textStyle: 'body1',
  display: 'flex',
  width: '440px',
  position: 'relative',
  overflow: 'hidden'
};

Alert.displayName = 'Alert';

export default Alert;