import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _extends from 'babel-runtime/helpers/extends';
import _Object$getPrototypeOf from 'babel-runtime/core-js/object/get-prototype-of';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Box from './Box';
import Text from './Text';
import theme from './theme';
var majorScale = theme.majorScale;

var AvatarImage = function (_Component) {
  _inherits(AvatarImage, _Component);

  function AvatarImage(props, context) {
    _classCallCheck(this, AvatarImage);

    var _this = _possibleConstructorReturn(this, (AvatarImage.__proto__ || _Object$getPrototypeOf(AvatarImage)).call(this, props, context));

    _this.handleError = _this.handleError.bind(_this);
    _this.state = {
      failed: false
    };
    return _this;
  }

  _createClass(AvatarImage, [{
    key: 'handleError',
    value: function handleError() {
      this.setState({ failed: true });
    }
  }, {
    key: 'render',
    value: function render() {
      if (this.state.failed || !this.props.src) return null;
      return React.createElement(Box, _extends({
        is: 'img',
        src: this.props.src,
        onError: this.handleError,
        height: '100%',
        width: '100%'
      }, this.props));
    }
  }]);

  return AvatarImage;
}(Component);

var AvatarName = function AvatarName(_ref) {
  var children = _ref.children;

  return React.createElement(
    Text,
    { textStyle: 'body1', truncate: true },
    children
  );
};

var AvatarCircle = function AvatarCircle(props) {
  return React.createElement(Box, _extends({ display: 'inline-block', circle: true, overflow: 'hidden' }, props));
};

var AvatarInitials = function AvatarInitials(props) {
  return React.createElement(Text, _extends({ top: '0', position: 'absolute', white: true }, props));
};

function getInitials(name) {
  if (!name || typeof name !== 'string') return '?';
  return name.replace(/\s+/, ' ').split(' ').slice(0, 2).map(function (v) {
    return v[0];
  }).join('');
}

var AvatarImageSize = {
  small: majorScale(4),
  default: majorScale(5)
};

var Avatar = function Avatar(_ref2) {
  var src = _ref2.src,
      imageSize = _ref2.imageSize,
      initialsFontSize = _ref2.initialsFontSize,
      children = _ref2.children,
      nameShown = _ref2.nameShown,
      width = _ref2.width,
      nameWidth = _ref2.nameWidth,
      backgroundColor = _ref2.backgroundColor,
      props = _objectWithoutProperties(_ref2, ['src', 'imageSize', 'initialsFontSize', 'children', 'nameShown', 'width', 'nameWidth', 'backgroundColor']);

  var size = AvatarImageSize.hasOwnProperty(imageSize) ? AvatarImageSize[imageSize] : imageSize;

  return React.createElement(
    Box,
    _extends({ title: children, textAlign: 'center' }, props),
    React.createElement(
      AvatarCircle,
      {
        position: 'relative',
        backgroundColor: backgroundColor,
        width: size,
        height: size
      },
      React.createElement(AvatarImage, { src: src, position: 'relative', style: { zIndex: 1 } }),
      React.createElement(
        AvatarInitials,
        {
          width: size,
          height: size,
          textStyle: parseInt(size, 10) >= parseInt(AvatarImageSize.default, 10) ? 'body1' : 'body2',
          style: { lineHeight: size, fontSize: initialsFontSize }
        },
        getInitials(children)
      )
    ),
    nameShown ? React.createElement(
      AvatarName,
      { width: nameWidth },
      children
    ) : null
  );
};

Avatar.propTypes = {
  showName: PropTypes.bool,
  children: PropTypes.string,
  nameWidth: PropTypes.string,
  imageSize: PropTypes.oneOfType([PropTypes.string, PropTypes.oneOf(['small', 'default'])]),
  initialFontSize: PropTypes.string,
  backgroundColor: PropTypes.string
};

Avatar.defaultProps = {
  nameWidth: majorScale(13),
  display: 'inline-block',
  imageSize: 'default',
  nameShown: false,
  backgroundColor: theme.colors.primary
};

export default Avatar;