import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _Object$getPrototypeOf from 'babel-runtime/core-js/object/get-prototype-of';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import _extends from 'babel-runtime/helpers/extends';
import React from 'react';
import PropTypes from 'prop-types';
import pluralize from 'pluralize';
import Button from './Button';
import Chevron from './Chevron';
import Select from './Select';
import Pane from './Pane';
import offscreenCss from './utils/offscreenCss';
import { css } from 'glamor';
import abbreviateNumber from './utils/abbreviateNumber';
import theme from './theme';
var majorScale = theme.majorScale,
    minorScale = theme.minorScale;


var main = css({
  display: 'inline-block',
  textAlign: 'right'
});

var size = css({
  marginRight: majorScale(1)
});

var nav = css({
  marginLeft: majorScale(1)
});

function PaginationButton(_ref) {
  var disabled = _ref.disabled,
      onClick = _ref.onClick,
      direction = _ref.direction,
      double = _ref.double,
      label = _ref.label;

  return React.createElement(
    Button,
    {
      size: 'small',
      disabled: disabled,
      onClick: onClick,
      paddingX: '0',
      marginLeft: minorScale(1),
      title: label
    },
    React.createElement(
      'div',
      offscreenCss,
      label
    ),
    React.createElement(Chevron, { aim: direction }),
    double && React.createElement(Chevron, { aim: direction, marginLeft: '-7px' })
  );
}
PaginationButton.displayName = 'PaginationButton';
PaginationButton.propTypes = _extends({}, Pane.propTypes, {
  disabled: PropTypes.bool.isRequired,
  onClick: PropTypes.func.isRequired,
  direction: PropTypes.oneOf(['left', 'right']).isRequired,
  double: PropTypes.bool.isRequired,
  label: PropTypes.string.isRequired
});
PaginationButton.defaultProps = {
  disabled: false,
  double: false
};

var Pagination = function (_React$Component) {
  _inherits(Pagination, _React$Component);

  function Pagination() {
    _classCallCheck(this, Pagination);

    return _possibleConstructorReturn(this, (Pagination.__proto__ || _Object$getPrototypeOf(Pagination)).apply(this, arguments));
  }

  _createClass(Pagination, [{
    key: 'currentPage',
    value: function currentPage() {
      var _props = this.props,
          pageSize = _props.pageSize,
          currentPageNum = _props.currentPageNum;

      return currentPageNum > -1 ? 1 + currentPageNum * pageSize : 0;
    }
  }, {
    key: 'totalPages',
    value: function totalPages() {
      var _props2 = this.props,
          pageSize = _props2.pageSize,
          currentPageNum = _props2.currentPageNum,
          totalItemCount = _props2.totalItemCount;

      return Math.min((1 + currentPageNum) * pageSize, totalItemCount);
    }
  }, {
    key: 'parseProps',
    value: function parseProps(_ref2) {
      var itemName = _ref2.itemName,
          pageSize = _ref2.pageSize,
          onPageSizeChange = _ref2.onPageSizeChange,
          totalItemCount = _ref2.totalItemCount,
          currentPageNum = _ref2.currentPageNum,
          onCurrentPageNumChange = _ref2.onCurrentPageNumChange,
          firstPageNum = _ref2.firstPageNum,
          lastPageNum = _ref2.lastPageNum,
          hidePageSizeSelect = _ref2.hidePageSizeSelect,
          props = _objectWithoutProperties(_ref2, ['itemName', 'pageSize', 'onPageSizeChange', 'totalItemCount', 'currentPageNum', 'onCurrentPageNumChange', 'firstPageNum', 'lastPageNum', 'hidePageSizeSelect']);

      return props;
    }
  }, {
    key: 'render',
    value: function render() {
      var _props3 = this.props,
          itemName = _props3.itemName,
          pageSize = _props3.pageSize,
          onPageSizeChange = _props3.onPageSizeChange,
          totalItemCount = _props3.totalItemCount,
          currentPageNum = _props3.currentPageNum,
          onCurrentPageNumChange = _props3.onCurrentPageNumChange,
          firstPageNum = _props3.firstPageNum,
          lastPageNum = _props3.lastPageNum,
          hidePageSizeSelect = _props3.hidePageSizeSelect;

      return React.createElement(
        Pane,
        _extends({}, this.parseProps(this.props), { className: '' + main }),
        !hidePageSizeSelect && React.createElement(
          'span',
          { className: '' + size },
          React.createElement(
            Select,
            {
              inline: true,
              size: 'small',
              onChange: function onChange(e) {
                return onPageSizeChange(parseInt(e.target.value, 10));
              },
              value: pageSize
            },
            React.createElement(
              'option',
              { value: '25' },
              '25'
            ),
            React.createElement(
              'option',
              { value: '50' },
              '50'
            ),
            React.createElement(
              'option',
              { value: '100' },
              '100'
            )
          )
        ),
        this.currentPage(),
        '-',
        this.totalPages(),
        ' of',
        ' ',
        abbreviateNumber(totalItemCount),
        ' ',
        pluralize(itemName, totalItemCount),
        React.createElement(
          'span',
          { className: '' + nav },
          React.createElement(PaginationButton, {
            disabled: currentPageNum <= firstPageNum,
            onClick: function onClick() {
              return onCurrentPageNumChange(firstPageNum);
            },
            direction: 'left',
            double: true,
            label: 'First page'
          }),
          React.createElement(PaginationButton, {
            disabled: currentPageNum <= firstPageNum,
            onClick: function onClick() {
              return onCurrentPageNumChange(currentPageNum - 1);
            },
            direction: 'left',
            label: 'Previous page'
          }),
          React.createElement(PaginationButton, {
            disabled: currentPageNum >= lastPageNum,
            onClick: function onClick() {
              return onCurrentPageNumChange(currentPageNum + 1);
            },
            direction: 'right',
            label: 'Next page'
          }),
          React.createElement(PaginationButton, {
            disabled: currentPageNum >= lastPageNum,
            onClick: function onClick() {
              return onCurrentPageNumChange(lastPageNum);
            },
            direction: 'right',
            double: true,
            label: 'Last page'
          })
        )
      );
    }
  }]);

  return Pagination;
}(React.Component);

export default Pagination;

Pagination.displayName = 'Pagination';
Pagination.propTypes = {
  itemName: PropTypes.string.isRequired,
  pageSize: PropTypes.number.isRequired,
  onPageSizeChange: PropTypes.func,
  totalItemCount: PropTypes.number.isRequired,
  currentPageNum: PropTypes.number.isRequired,
  onCurrentPageNumChange: PropTypes.func.isRequired,
  firstPageNum: PropTypes.number.isRequired,
  lastPageNum: PropTypes.number.isRequired,
  hidePageSizeSelect: PropTypes.bool
};