import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _extends from 'babel-runtime/helpers/extends';
import _Object$getPrototypeOf from 'babel-runtime/core-js/object/get-prototype-of';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Transition from 'react-transition-group/Transition';
import { css } from 'glamor';
import theme from './theme';
import cx from 'classnames';
import objectValues from 'object-values';
var majorScale = theme.majorScale,
    animationDuration = theme.animationDuration,
    animationEasing = theme.animationEasing,
    colors = theme.colors,
    borderRadius = theme.borderRadius,
    popoverShadow = theme.popoverShadow;

import Box from './Box';
import Portal from './Portal';

var ANIMATION_DURATION = parseInt(animationDuration.slow, 10);

var styles = {};

styles.position = {
  position: 'absolute',
  transition: 'all ' + animationDuration.slow + ' ' + animationEasing.deceleration,
  '&.popover-hide': {
    opacity: '0'
  }
};

styles.animation = {
  transition: 'all ' + animationDuration.fast + ' ' + animationEasing.spring,
  transform: 'scale(0) translateY(-20px)',
  '&[data-position="bottom"]': {
    opacity: 1,
    visibility: 'visible',
    transform: 'scale(1) translateY(4px)'
  },
  '&[data-position="top"]': {
    opacity: 1,
    visibility: 'visible',
    transform: 'scale(1) translateY(-4px)'
  }
};

styles.arrow = {
  position: 'absolute',
  zIndex: 1,
  '&[data-position="bottom"]': {
    transform: 'translateY(-10px) translateX(-50%)'
  },
  '&[data-position="top"]': {
    bottom: 0,
    transform: 'translateY(10px) translateX(-50%)  rotate(180deg)'
  }
};

styles.content = {
  overflow: 'hidden',
  position: 'relative',
  minWidth: majorScale(20),
  border: '1px solid ' + colors.borderColor,
  borderRadius: borderRadius[0],
  boxShadow: popoverShadow,
  background: 'white'
};

var PopoverSides = {
  TOP: 'top',
  BOTTOM: 'bottom'
};

var PopoverBox = function (_Component) {
  _inherits(PopoverBox, _Component);

  function PopoverBox() {
    _classCallCheck(this, PopoverBox);

    var _this = _possibleConstructorReturn(this, (PopoverBox.__proto__ || _Object$getPrototypeOf(PopoverBox)).call(this));

    _this.state = _this.initialState();

    _this.handleEnter = _this.handleEnter.bind(_this);
    _this.handleEntering = _this.handleEntering.bind(_this);
    _this.handleExiting = _this.handleExiting.bind(_this);
    _this.handleExited = _this.handleExited.bind(_this);
    return _this;
  }

  _createClass(PopoverBox, [{
    key: 'initialState',
    value: function initialState() {
      return {
        top: null,
        left: null,
        arrowLeft: null,
        side: null
      };
    }
  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      var _props = this.props,
          children = _props.children,
          onRef = _props.onRef,
          isOpen = _props.isOpen,
          useArrow = _props.useArrow,
          zIndex = _props.zIndex;
      var _state = this.state,
          top = _state.top,
          left = _state.left,
          arrowLeft = _state.arrowLeft,
          side = _state.side;


      var transformOrigin = arrowLeft + 'px ' + (side === PopoverSides.BOTTOM ? '-20px' : 'bottom');

      var arrowStyle = _extends({}, useArrow ? {
        left: arrowLeft
      } : {
        display: 'none'
      });

      return React.createElement(
        Portal,
        null,
        React.createElement(
          Transition,
          {
            'in': isOpen,
            timeout: ANIMATION_DURATION,
            unmountOnExit: true,
            onEnter: this.handleEnter,
            onEntering: this.handleEntering,
            onExiting: this.handleExiting,
            onExited: this.handleExited
          },
          React.createElement(
            'div',
            _extends({}, css(styles.position), {
              style: { left: left, top: top, zIndex: zIndex },
              ref: function ref(node) {
                _this2.position = node;onRef(node);
              },
              'data-position': side,
              'data-alignment': 'center'
            }),
            React.createElement(
              'div',
              _extends({ style: { transformOrigin: transformOrigin } }, css(styles.animation), { ref: function ref(node) {
                  _this2.animation = node;
                } }),
              React.createElement(
                'svg',
                _extends({ 'data-position': side, style: arrowStyle }, css(styles.arrow), { ref: function ref(node) {
                    _this2.arrow = node;
                  }, width: '26', height: '11', viewBox: '0 0 26 11', xmlns: 'http://www.w3.org/2000/svg' }),
                React.createElement('path', { d: 'M21.698 8.11c.936 1.015 2.922 1.887 4.297 1.887h-26c1.378 0 3.357-.868 4.297-1.888L10.91.92c1.14-1.237 3.034-1.233 4.17 0l6.618 7.185z', fill: '#E4EDF5' }),
                React.createElement('path', { d: 'M20.964 8.787c1.125 1.22 3.376 2.21 5.03 2.21H28-2 .005c1.654 0 3.9-.983 5.03-2.21l6.616-7.183c.75-.81 1.96-.802 2.7 0l6.62 7.183z', fill: '#FFF' })
              ),
              React.createElement(
                'div',
                css(styles.content),
                children
              )
            )
          )
        )
      );
    }
  }, {
    key: 'handleEnter',
    value: function handleEnter() {
      var useSmartPositioning = this.props.useSmartPositioning;
      var _props$anchors = this.props.anchors,
          top = _props$anchors.top,
          bottom = _props$anchors.bottom;

      var side = this.props.side;

      // Smartly position the popover when it overflows the body
      var popoverRect = this.position.getBoundingClientRect();
      var viewportHeight = document.documentElement.clientHeight + window.scrollY;
      var viewportWidth = document.documentElement.clientWidth + window.scrollX;

      if (useSmartPositioning && popoverRect.height + bottom.y > viewportHeight) {
        side = 'top';
      }

      this.animation.setAttribute('data-position', side);
      var OFFSET = 4;

      var left = Math.max(bottom.x - popoverRect.width / 2, OFFSET);
      left = Math.min(left, viewportWidth - popoverRect.width - OFFSET);

      var arrowLeft = void 0;
      if (popoverRect.width / 2 - OFFSET < bottom.x) {
        arrowLeft = popoverRect.width / 2 - OFFSET;
        arrowLeft = Math.max(arrowLeft, bottom.x - left);
      } else {
        arrowLeft = bottom.x;
        arrowLeft = Math.max(arrowLeft - OFFSET, bottom.x - left);
      }

      this.setState({
        left: left,
        side: side,
        top: side === PopoverSides.BOTTOM ? bottom.y : top.y - popoverRect.height,
        arrowLeft: arrowLeft
      });
    }
  }, {
    key: 'handleEntering',
    value: function handleEntering() {
      this.position.classList.add('popover-show');
      this.position.classList.remove('popover-hide');
    }
  }, {
    key: 'handleExiting',
    value: function handleExiting() {
      this.position.classList.remove('popover-show');
      this.position.classList.add('popover-hide');
    }
  }, {
    key: 'handleExited',
    value: function handleExited() {
      this.setState(this.initialState());
    }
  }]);

  return PopoverBox;
}(Component);

PopoverBox.propTypes = {
  children: PropTypes.node.isRequired,
  onRef: PropTypes.func.isRequired,
  isOpen: PropTypes.bool.isRequired,
  side: PropTypes.oneOf(objectValues(PopoverSides)),
  anchors: PropTypes.shape({
    top: PropTypes.shape({
      x: PropTypes.number,
      y: PropTypes.number
    }),
    bottom: PropTypes.shape({
      x: PropTypes.number,
      y: PropTypes.number
    })
  }),
  useArrow: PropTypes.bool,
  useSmartPositioning: PropTypes.bool,
  zIndex: PropTypes.number
};

PopoverBox.defaultProps = {
  onRef: function onRef() {}
};

PopoverBox.displayName = 'PopoverBox';

var Popover = function (_Component2) {
  _inherits(Popover, _Component2);

  function Popover() {
    _classCallCheck(this, Popover);

    var _this3 = _possibleConstructorReturn(this, (Popover.__proto__ || _Object$getPrototypeOf(Popover)).call(this));

    _this3.state = {
      isOpen: false,
      anchors: {
        top: {
          x: 0,
          y: 0
        },
        bottom: {
          x: 0,
          y: 0
        }
      }
    };

    _this3.onButtonClick = _this3.onButtonClick.bind(_this3);
    _this3.onBodyClick = _this3.onBodyClick.bind(_this3);
    _this3.onResize = _this3.onResize.bind(_this3);
    _this3.handleRef = _this3.handleRef.bind(_this3);
    _this3.onEsc = _this3.onEsc.bind(_this3);
    _this3.close = _this3.close.bind(_this3);
    return _this3;
  }

  _createClass(Popover, [{
    key: 'render',
    value: function render() {
      var _this4 = this;

      var _props2 = this.props,
          onOpen = _props2.onOpen,
          onClose = _props2.onClose,
          children = _props2.children,
          content = _props2.content,
          openClass = _props2.openClass,
          side = _props2.side,
          useSmartPositioning = _props2.useSmartPositioning,
          useArrow = _props2.useArrow,
          zIndexContent = _props2.zIndexContent,
          props = _objectWithoutProperties(_props2, ['onOpen', 'onClose', 'children', 'content', 'openClass', 'side', 'useSmartPositioning', 'useArrow', 'zIndexContent']);

      var _state2 = this.state,
          isOpen = _state2.isOpen,
          anchors = _state2.anchors;


      return React.createElement(
        Box,
        _extends({}, props, { onRef: function onRef(node) {
            _this4.wrapper = node;
          } }),
        React.cloneElement(children, {
          className: cx(children.props.className, isOpen && openClass),
          onClick: this.onButtonClick
        }),
        React.createElement(
          PopoverBox,
          {
            isOpen: isOpen,
            zIndex: zIndexContent,
            onRef: this.handleRef,
            anchors: anchors,
            side: side,
            useSmartPositioning: useSmartPositioning,
            useArrow: useArrow
          },
          typeof content === 'function' ? content({ close: this.close }) : content
        )
      );
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      document.body.removeEventListener('click', this.onBodyClick, false);
      document.body.removeEventListener('keydown', this.onEsc, false);
      window.removeEventListener('resize', this.resize, false);
    }
  }, {
    key: 'handleRef',
    value: function handleRef(node) {
      this.popoverNode = node;
    }
  }, {
    key: 'getAnchors',
    value: function getAnchors() {
      var targetRect = this.wrapper.childNodes[0].getBoundingClientRect();
      var bodyRect = document.body.getBoundingClientRect();
      var x = targetRect.left + targetRect.width / 2;
      return {
        top: {
          x: x,
          y: targetRect.top - bodyRect.top
        },
        bottom: {
          x: x,
          y: targetRect.bottom - bodyRect.top
        }
      };
    }
  }, {
    key: 'onButtonClick',
    value: function onButtonClick(e) {
      var isOpen = !this.state.isOpen;

      if (isOpen) {
        this.open();
      } else {
        this.close();
      }

      this.setState({ isOpen: isOpen });
    }
  }, {
    key: 'onBodyClick',
    value: function onBodyClick(e) {
      // Ignore clicks on the popover or button
      if (this.wrapper === e.target || this.wrapper.contains(e.target)) {
        return;
      }

      if (this.popoverNode && (this.popoverNode === e.target || this.popoverNode.contains(e.target))) {
        return;
      }

      this.close();
    }
  }, {
    key: 'onEsc',
    value: function onEsc(e) {
      // esc key
      if (e.keyCode === 27) {
        this.close();
      }
    }
  }, {
    key: 'onResize',
    value: function onResize() {
      this.close();
    }
  }, {
    key: 'open',
    value: function open() {
      if (this.state.isOpen) {
        return;
      }

      this.setState({ isOpen: true, anchors: this.getAnchors() });
      document.body.addEventListener('click', this.onBodyClick, false);
      document.body.addEventListener('keydown', this.onEsc, false);
      window.addEventListener('resize', this.onResize, false);

      this.props.onOpen();
    }
  }, {
    key: 'close',
    value: function close() {
      if (!this.state.isOpen) {
        return;
      }

      this.setState({ isOpen: false });
      document.body.removeEventListener('click', this.onBodyClick, false);
      document.body.removeEventListener('keydown', this.onEsc, false);
      window.removeEventListener('resize', this.resize, false);

      this.props.onClose();
    }
  }]);

  return Popover;
}(Component);

Popover.propTypes = _extends({}, Box.propTypes, {
  children: PropTypes.element.isRequired,
  content: PropTypes.oneOfType([PropTypes.node, PropTypes.func]).isRequired,
  openClass: PropTypes.string,
  onOpen: PropTypes.func.isRequired,
  onClose: PropTypes.func.isRequired,
  side: PropTypes.oneOf(objectValues(PopoverSides)),
  useArrow: PropTypes.bool,
  useSmartPositioning: PropTypes.bool,
  zIndexContent: PropTypes.number
});

Popover.defaultProps = {
  side: PopoverSides.BOTTOM,
  openClass: theme.activeClassName,
  onOpen: function onOpen() {},
  onClose: function onClose() {},
  useArrow: false,
  useSmartPositioning: true,
  zIndexContent: 50
};

Popover.displayName = 'Popover';

export default Popover;