import _Object$keys from 'babel-runtime/core-js/object/keys';
import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import cx from 'classnames';
import Box from './Box';
import SearchIcon from './SearchIcon';
import theme from './theme';
import splitProps from './utils/splitProps';
import { InputAppearances } from 'evergreen-shared-styles';
var minorScale = theme.minorScale,
    majorScale = theme.majorScale,
    textColors = theme.textColors;


var styles = css(InputAppearances.default);

function useControlSizes(_ref) {
  var size = _ref.size,
      props = _objectWithoutProperties(_ref, ['size']);

  var sizes = theme.controlSizes[size];

  return _extends({
    minHeight: sizes.minHeight,
    minWidth: sizes.minWidth,
    textStyle: sizes.textStyle,
    paddingX: size === 'small' ? minorScale(3) : majorScale(2),
    paddingLeft: size === 'small' ? majorScale(4) : minorScale(9)
  }, props);
}

var SearchInput = function SearchInput(_ref2) {
  var className = _ref2.className,
      props = _objectWithoutProperties(_ref2, ['className']);

  // Tries to treat this component as a single box
  var _splitProps = splitProps(useControlSizes(props), /margin|width|height|display|flex|alignItems|justifyContent|flexDirection|flexGrow|flexShrink/gi),
      matchedProps = _splitProps.matchedProps,
      unmatchedProps = _splitProps.unmatchedProps;

  return React.createElement(
    Box,
    _extends({ position: 'relative', display: 'flex' }, matchedProps),
    React.createElement(SearchIcon, {
      size: 'small',
      position: 'absolute',
      top: '50%',
      marginLeft: props.size === 'small' ? minorScale(2) : minorScale(3),
      marginTop: majorScale(-1),
      fill: textColors.muted,
      style: {
        zIndex: 4,
        pointerEvents: 'none'
      }
    }),
    React.createElement(Box, _extends({
      is: 'input',
      className: cx('' + styles, className),
      flex: '1',
      rounded: true
    }, unmatchedProps))
  );
};

SearchInput.propTypes = _extends({}, Box.propTypes, {
  size: PropTypes.oneOf(_Object$keys(theme.controlSizes))
});

SearchInput.defaultProps = {
  size: 'default'
};

SearchInput.displayName = 'SearchInput';

export default SearchInput;