import _Object$keys from 'babel-runtime/core-js/object/keys';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _typeof from 'babel-runtime/helpers/typeof';
import _extends from 'babel-runtime/helpers/extends';
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import Box from './Box';
import DoubleTriangle from './DoubleTriangle';
import theme from './theme';
import splitProps from './utils/splitProps';
import { SelectAppearances } from 'evergreen-select';
var minorScale = theme.minorScale,
    majorScale = theme.majorScale,
    controlSizes = theme.controlSizes;


var selectStyles = css(SelectAppearances.default);
var SelectWrapperBox = function SelectWrapperBox(props) {
  return React.createElement(Box, props);
};
SelectWrapperBox.displayName = 'SelectWrapperBox';

var iconStyles = css({
  position: 'absolute',
  transform: 'translateY(-50%)',
  pointerEvents: 'none',
  top: '50%'
});
var SelectIcon = function SelectIcon(props) {
  return React.createElement(DoubleTriangle, _extends({ className: '' + iconStyles }, props));
};
SelectIcon.displayName = 'SelectIcon';

var renderOptions = function renderOptions() {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

  return options.map(function (item) {
    return (typeof item === 'undefined' ? 'undefined' : _typeof(item)) === 'object' ? item : { value: item, label: item };
  }).map(function (item, i) {
    return React.createElement(
      'option',
      { key: 'option__' + item.value + '__' + i, value: item.value },
      item.label
    );
  });
};

function useControlSizes(_ref) {
  var size = _ref.size,
      inline = _ref.inline,
      props = _objectWithoutProperties(_ref, ['size', 'inline']);

  var sizes = controlSizes[size];

  return _extends({
    display: inline ? 'inline-flex' : 'flex',
    minHeight: sizes.minHeight,
    minWidth: sizes.minWidth,
    textStyle: sizes.textStyle,
    paddingLeft: size === 'small' ? minorScale(3) : majorScale(2),
    paddingRight: size === 'small' ? majorScale(3) : majorScale(4)
  }, props);
}

var Select = function Select(_ref2) {
  var options = _ref2.options,
      children = _ref2.children,
      props = _objectWithoutProperties(_ref2, ['options', 'children']);

  var _splitProps = splitProps(useControlSizes(props), /margin|width|height|display|flex|alignItems|justifyContent|flexDirection|flexGrow|flexShrink/gi),
      matchedProps = _splitProps.matchedProps,
      unmatchedProps = _splitProps.unmatchedProps;

  return React.createElement(
    SelectWrapperBox,
    _extends({ position: 'relative' }, matchedProps),
    React.createElement(SelectIcon, {
      right: props.size === 'small' ? majorScale(1) : minorScale(3)
    }),
    React.createElement(
      Box,
      _extends({ className: '' + selectStyles, flex: '1' }, unmatchedProps),
      options ? renderOptions(options) : children
    )
  );
};

Select.propTypes = {
  options: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.string), PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.string,
    label: PropTypes.string
  }))]),
  size: PropTypes.oneOf(_Object$keys(controlSizes)).isRequired,
  inline: PropTypes.bool.isRequired
};

Select.defaultProps = {
  is: 'select',
  rounded: true,
  size: 'default',
  inline: false
};

Select.displayName = 'Select';

export default Select;