import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _Number$isInteger from 'babel-runtime/core-js/number/is-integer';
import PropTypes from 'prop-types';
import theme from '../components/theme';

var RoundedPropType = PropTypes.oneOfType([PropTypes.bool, PropTypes.oneOf(theme.borderRadius.map(function (_, i) {
  return i + 1;
})), PropTypes.string]);

export var propTypes = {
  circle: PropTypes.bool,
  rounded: RoundedPropType,
  roundedTop: RoundedPropType,
  roundedTopLeft: RoundedPropType,
  roundedTopRight: RoundedPropType,
  roundedBottom: RoundedPropType,
  roundedBottomLeft: RoundedPropType,
  roundedBottomRight: RoundedPropType,
  roundedLeft: RoundedPropType,
  roundedRight: RoundedPropType
};

var parseUnit = function parseUnit(unit) {
  if (unit === undefined) {
    return '0';
  } else if (typeof unit === 'boolean') {
    return theme.borderRadius[0];
  } else if (_Number$isInteger(unit)) {
    return theme.borderRadius[unit - 1];
  }
  return unit;
};

var parseBorderRadius = function parseBorderRadius(_ref) {
  var topLeft = _ref.topLeft,
      topRight = _ref.topRight,
      bottomLeft = _ref.bottomLeft,
      bottomRight = _ref.bottomRight;
  return parseUnit(topLeft) + ' ' + parseUnit(topRight) + ' ' + parseUnit(bottomRight) + ' ' + parseUnit(bottomLeft);
};

var getFirstValidValue = function getFirstValidValue() {
  for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  for (var i = 0, len = args.length; i < len; i++) {
    if (args[i] !== undefined) {
      return args[i];
    }
  }
};

var parseProps = function parseProps(_ref2) {
  var circle = _ref2.circle,
      rounded = _ref2.rounded,
      roundedTop = _ref2.roundedTop,
      roundedTopLeft = _ref2.roundedTopLeft,
      roundedTopRight = _ref2.roundedTopRight,
      roundedBottom = _ref2.roundedBottom,
      roundedBottomLeft = _ref2.roundedBottomLeft,
      roundedBottomRight = _ref2.roundedBottomRight,
      roundedLeft = _ref2.roundedLeft,
      roundedRight = _ref2.roundedRight,
      style = _ref2.style,
      props = _objectWithoutProperties(_ref2, ['circle', 'rounded', 'roundedTop', 'roundedTopLeft', 'roundedTopRight', 'roundedBottom', 'roundedBottomLeft', 'roundedBottomRight', 'roundedLeft', 'roundedRight', 'style']);

  var styles = {};

  if (circle) styles.borderRadius = '9999px';else if (rounded !== undefined || roundedTop !== undefined || roundedTopLeft !== undefined || roundedTopRight !== undefined || roundedBottom !== undefined || roundedBottomLeft !== undefined || roundedBottomRight !== undefined || roundedLeft !== undefined || roundedRight !== undefined) {
    styles.borderRadius = parseBorderRadius({
      topLeft: getFirstValidValue(roundedTopLeft, roundedTop, roundedLeft, rounded),
      topRight: getFirstValidValue(roundedTopRight, roundedTop, roundedRight, rounded),
      bottomLeft: getFirstValidValue(roundedBottomLeft, roundedBottom, roundedLeft, rounded),
      bottomRight: getFirstValidValue(roundedBottomRight, roundedBottom, roundedRight, rounded)
    });
  }

  return _extends({ style: _extends({}, styles, style) }, props);
};
export { parseProps };