import React from 'react';
import { storiesOf } from '@storybook/react';
import { App, Pane, Avatar, Box, Triangle, theme } from '../components';
import Content from './Content';
var minorScale = theme.minorScale,
    majorScale = theme.majorScale;


var imageURL = 'http://www.casinomeister.com/forums/avatars/jufo.gif?dateline=1345999507';

export default function avatarStory(module) {
  storiesOf('Avatar', module).add('usage', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { white: true, padding: majorScale(10) },
        React.createElement(
          Content,
          { markdown: true },
          '\n# Avatar\n\nThe Avatar component allows easy avatar composition. Implements `<Box />`.\n\n* Falls back to initials on error\n* Adds a title attribute with the name\n\n```\nconst imageURL = \'' + imageURL + '\'\n\n<Avatar src={imageURL}>Segment Sloth</Avatar>\n<Avatar nameShown src=\'http://www.example.com/BAD_URL\'>Segment Sloth</Avatar>\n<Avatar src=\'https://secure.gravatar.com/avatar/01ee3e7d9562c34f5e38b338250e42ec.jpg?s=40d=blank\'>Blank Image</Avatar>\n```\n\n'
        ),
        React.createElement(
          Avatar,
          { marginRight: minorScale(2), src: imageURL },
          'Segment Sloth'
        ),
        React.createElement(
          Avatar,
          { nameShown: true, src: 'http://www.example.com/BAD_URL' },
          'Segment Sloth'
        ),
        React.createElement(
          Avatar,
          { src: 'https://secure.gravatar.com/avatar/01ee3e7d9562c34f5e38b338250e42ec.png?s=40d=blank' },
          'Blank Image'
        ),
        React.createElement(
          Content,
          { markdown: true },
          '\nprop | type | default | description\n-----|------| --------|-------------\n`children`| string | undefined | the name of the avatar/person displayed\n`imageSize`| string / small, default | 40px | the width and height of the image\n`nameShown`| boolean | false | wether to show a name under the Avatar\n'
        )
      )
    );
  }).add('with circle only', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { white: true, padding: majorScale(3), clearfix: true },
        React.createElement(
          Avatar,
          { marginLeft: majorScale(1), marginRight: majorScale(1), src: imageURL },
          'Segment Sloth'
        ),
        React.createElement(
          Avatar,
          { marginLeft: majorScale(1), marginRight: majorScale(1), src: 'http://www.example.com/badurl' },
          'Segment Sloth'
        )
      )
    );
  }).add('with name shown', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { white: true, padding: majorScale(3), clearfix: true },
        React.createElement(
          Avatar,
          { nameShown: true, marginLeft: majorScale(1), marginRight: majorScale(1), src: imageURL },
          'Segment Sloth'
        ),
        React.createElement(
          Avatar,
          { nameShown: true, marginLeft: majorScale(1), marginRight: majorScale(1), src: 'http://www.example.com/badurl' },
          'Segment Sloth'
        )
      )
    );
  }).add('with Triangle', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { white: true, padding: majorScale(3), clearfix: true },
        React.createElement(
          Box,
          { display: 'flex', alignItems: 'center' },
          React.createElement(
            Avatar,
            { marginLeft: majorScale(1), marginRight: majorScale(1), src: imageURL },
            'Segment Sloth'
          ),
          React.createElement(Triangle, { aim: 'down', display: 'inline-flex' })
        )
      )
    );
  }).add('standalone', function () {
    return React.createElement(
      Avatar,
      { marginLeft: majorScale(1), marginRight: majorScale(1), src: imageURL },
      'Segment Sloth'
    );
  });
}