import _Object$keys from 'babel-runtime/core-js/object/keys';
import React from 'react';
import { storiesOf } from '@storybook/react';
import { App, Box, Code, Pane, theme } from '../components';
import Content from './Content';
var majorScale = theme.majorScale;


export default function boxStory(module) {
  storiesOf('Box', module).add('usage', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { white: true, padding: majorScale(10) },
        React.createElement(
          Content,
          { markdown: true },
          '\n# Box\n\nThe Box component is the base component for most other components, by default it is a `div`.\nAll the higher order components in `enhancers` are applied to Box.\n\n## is=\'...\' API\n\n```\n<Box>div by default</Box>\n<Box is=\'span\'>now a span</Box>\n<Box is=\'h1\'>now a h1</Box>\n<Box is=\'a\'>now a anchor tag</Box>\n<Box is={Link}>now a Link, use with caution</Box>\n```\n\n## Display API\n\nAvailable on `<Box />` or `withDisplay(Comp)`.\nUses inline styles.\n\n```\n<Box display=\'block\' />\n<Box display=\'inline-block\' />\n<Box display=\'flex\' />\n```\n\nprop | value | description\n-----|-------|-------------\n`display`| block, inline-block, inline, table, table-row, table-cell, flex, inline-flex | display: x;\n\n## Dimensions API\n\nAvailable on `<Box />` or `withDimensions(Comp)`.\nUses inline styles.\n\n```\n<Box width=\'200px\' />\n<Box height=\'40px\' />\n<Box height=\'40px\' width=\'40px\' />\n<Box minWidth=\'100px\' />\n```\n\nprop | type | description\n-----|------| -------\n`height`| string | height: x;\n`width`| string | width: x;\n`minWidth`| string | min-width: x;\n`minHeight`| string | min-height: x;\n`maxWidth`| string | max-width: x;\n`maxHeight`| string | max-height: x;\n\n## Text Styles API\n\nAvailable on `<Box />` or `withTextStyles(Comp)`. Uses glamor.\n\n```\n<Box textStyle=\'display1\'>Display (1)</Box>\n<Box textStyle=\'display2\'>Display 2</Box>\n<Box textStyle=\'display3\'>Display 3</Box>\n<Box textStyle=\'display4\'>Display 4</Box>\n<Box textStyle=\'display5\'>Display 5</Box>\n<Box textStyle=\'body1\'>Body (1)</Box>\n<Box textStyle=\'body2\'>Body 2</Box>\n<Box textStyle=\'mono\'>Mono</Box>\n<Box textStyle=\'caps1\'>Caps 1</Box>\n<Box textStyle=\'caps2\'>Caps 2</Box>\n```\n\n'
        ),
        React.createElement(
          Box,
          { textStyle: 'display1' },
          'Display (1)'
        ),
        React.createElement(
          Box,
          { textStyle: 'display2' },
          'Display 2'
        ),
        React.createElement(
          Box,
          { textStyle: 'display3' },
          'Display 3'
        ),
        React.createElement(
          Box,
          { textStyle: 'display4' },
          'Display 4'
        ),
        React.createElement(
          Box,
          { textStyle: 'display5' },
          'Display 5'
        ),
        React.createElement(
          Box,
          { textStyle: 'body1' },
          'Body (1)'
        ),
        React.createElement(
          Box,
          { textStyle: 'body2' },
          'Body 2'
        ),
        React.createElement(
          Box,
          { textStyle: 'mono' },
          'Mono'
        ),
        React.createElement(
          Box,
          { textStyle: 'caps1' },
          'Caps 1'
        ),
        React.createElement(
          Box,
          { textStyle: 'caps2' },
          'Caps 2'
        ),
        React.createElement(
          Content,
          { markdown: true },
          '\n\nprop | type | description\n-----|------|------------\n`textStyle` | display1, display2, display3, display4, body1, body2, mono, caps1, caps2 | use text style\n\n## Spacing API\n\nAvailable on `<Box />` or `withSpacing(Comp)`.\nUses inline styles. Uses the spacing scale.\n\n```\n<Box padding={majorScale(2)} />\n<Box margin={majorScale(2)} />\n<Box paddingTop={minorScale(3)} paddingBottom={minorScale(3)} />\n\n<!-- DANGER: Avoid this as much as possible -->\n<Box marginTop=\'-2px\' />\n```\n\nprop | type | description\n-----|------| -------\n`padding` | string | padding: x;\n`paddingTop` | string | padding-top: x;\n`paddingRight` | string | padding-right: x;\n`paddingBottom` | string | padding-bottom: x;\n`paddingLeft` | string | padding-left: x;\n`paddingLeft` | string | padding-left: x;\n`paddingX` | string | padding-left: x; padding-right: x;\n`paddingY` | string | padding-top: x; padding-bottom: x;\n`marginTop` | string | margin-top: x;\n`marginRight` | string | margin-right: x;\n`marginBottom` | string | margin-bottom: x;\n`marginLeft` | string | margin-left: x;\n`marginX` | string | margin-left: x; margin-right: x;\n`marginY` | string | margin-top: x; margin-bottom: x;\n\n### Spacing Scale\n\n```\nimport {\n  theme\n} from \'@segment/react-ui-library\'\nconst { minorScale, majorScale } = theme\n```\n\nThese scales are super simple:\n\n```\nconst majorScale = x => `${x * 8}px`\nconst minorScale = x => `${x * 4}px`\n```\n\n# Flex API\n\nUses glamor.\n\nNeed a flexbox refresher? [Complete guide to flexbox](https://css-tricks.com/snippets/css/a-guide-to-flexbox/)\n\n```\n<Box display=\'flex\'>\n  <Pane dark padding={majorScale(2)} width=\'25%\'>Left</Pane>\n  <Pane tint={2} padding={majorScale(2)} flexAuto>Main</Pane>\n  <Pane dark padding={majorScale(2)} width=\'25%\'>Right</Pane>\n</Box>\n```\n'
        ),
        React.createElement(
          Box,
          { display: 'flex' },
          React.createElement(
            Pane,
            { dark: true, padding: majorScale(2), width: '25%', flex: '0 0 auto' },
            'Left'
          ),
          React.createElement(
            Pane,
            { tint: 2, flexAuto: true, padding: majorScale(2) },
            'Main'
          ),
          React.createElement(
            Pane,
            { dark: true, padding: majorScale(2), width: '25%', flex: '0 0 auto' },
            'Right'
          )
        ),
        React.createElement(
          Content,
          { markdown: true },
          '\nprop | type | description\n-----|------|------------\n`flex`    | string | flex: x;\n`flexWrap`    | boolean | flex-wrap: wrap\n`flexAlign`   | string  | align-items\n`justifyContent` | center, space-around, space-between, flex-start, flex-end  | justify-content\n`flexDirection`| row, row-reverse, column, column-reverse | flex-direction: x\n`flexColumn`| boolean | flex-direction: column; overwrites `flexDirection`\n`flexGrow`| string | flex-grow: x\n`flexShrink`| string | flex-shrink: x\n`flexAuto`| boolean | flex: 1 1 auto\n`flexNone`| boolean | flex: none\n`flexOrder`   | number  | order\n\n## Borders API\n\nUses inline styles.\n\nSome components implement a border color already, such as Pane.\n\nprop | type | description\n-----|------|------------\n`borderColor` | string | border-color: x;\n`border` | boolean | border: 1px solid;\n`borderLeft` | boolean | border-left: 1px solid;\n`borderRight` | boolean | border-right: 1px solid;\n`borderTop` | boolean | border-top: 1px solid;\n`borderBottom` | boolean | border-bottom: 1px solid;\n\n## Position API\n\nUses inline styles.\n\nprop | type | description\n-----|------|------------\n`position` | relative, absolute, fixed, static | position: x;\n`top` | string | top: x;\n`right` | string | right: x;\n`bottom` | string | bottom: x;\n`left` | string | left: x;\n\n## Rounded API (border radius)\n\nAvailable on `<Box />` or `withRounded(Comp)`. Uses inline styles.\n\nprop | type | description\n-----|------|------------\n`circle` | bool | border-radius: 9999px\n`rounded` | bool/1..2/string | adds border radius\n`roundedTop` | bool/1..2/string | adds border radius\n`roundedTopLeft` | bool/1..2/string | adds border radius\n`roundedTopRight` | bool/1..2/string | adds border radius\n`roundedBottom` | bool/1..2/string | adds border radius\n`roundedBottomLeft` | bool/1..2/string | adds border radius\n`roundedBottomRight` | bool/1..2/string | adds border radius\n`roundedLeft` | bool/1..2/string | adds border radius\n`roundedRight` | bool/1..2/string | adds border radius\n\nThe borderRadius scale contains 1: \'5px\' and 2: \'8px\'\n\n'
        ),
        React.createElement(
          Pane,
          { marginY: majorScale(2), padding: majorScale(2), dark: true, circle: true },
          'circle'
        ),
        React.createElement(
          Pane,
          { marginY: majorScale(2), padding: majorScale(2), dark: true, rounded: true },
          'rounded'
        ),
        React.createElement(
          Pane,
          { marginY: majorScale(2), padding: majorScale(2), dark: true, roundedTop: true },
          'roundedTop'
        ),
        React.createElement(
          Pane,
          { marginY: majorScale(2), padding: majorScale(2), dark: true, roundedTopLeft: true },
          'roundedTopLeft'
        ),
        React.createElement(
          Pane,
          { marginY: majorScale(2), padding: majorScale(2), dark: true, roundedTopRight: true },
          'roundedTopRight'
        ),
        React.createElement(
          Pane,
          { marginY: majorScale(2), padding: majorScale(2), dark: true, roundedBottom: true },
          'roundedBottom'
        ),
        React.createElement(
          Pane,
          { marginY: majorScale(2), padding: majorScale(2), dark: true, roundedBottomLeft: true },
          'roundedBottomLeft'
        ),
        React.createElement(
          Pane,
          { marginY: majorScale(2), padding: majorScale(2), dark: true, roundedBottomRight: true },
          'roundedBottomRight'
        ),
        React.createElement(
          Pane,
          { marginY: majorScale(2), padding: majorScale(2), dark: true, roundedLeft: true },
          'roundedLeft'
        ),
        React.createElement(
          Pane,
          { marginY: majorScale(2), padding: majorScale(2), dark: true, roundedRight: true },
          'roundedRight'
        ),
        React.createElement(
          Content,
          { markdown: true },
          '\n\n## Overflow API\n\nAvailable on `<Box />` or `withOverflow(Comp)`. Uses inline styles.\n\nprop | type | description\n-----|------|------------\n`overflow` | hidden, visible, scroll, auto, inherit, initial | overflow: x;\n\n\n## Shadow API\n\nAvailable on `<Box />` or `withShadow(Comp)`. Uses glamor.\n\nprop | type | description\n-----|------|------------\n`shadow` | boolean/1..2 | 1 | box-shadow: x;\n\n'
        ),
        React.createElement(
          Pane,
          { tint: 2, clearfix: true },
          React.createElement(
            Pane,
            { white: true, padding: majorScale(2), margin: majorScale(2), rounded: true, shadow: true },
            'Shadow (1)'
          ),
          React.createElement(
            Pane,
            { white: true, padding: majorScale(2), margin: majorScale(2), rounded: true, shadow: 2 },
            'Shadow 2'
          )
        ),
        React.createElement(
          Content,
          { markdown: true },
          '\n\n## Text Align API\n\nAvailable on `<Box />` or `withTextAlign(Comp)`. Uses inline styles.\n\nprop | type | description\n-----|------|------------\n`textAlign` | left, center, right | text-align: x;\n\n## Truncate API\n\nAvailable on `<Box />` or `withTruncate(Comp)`. Uses inline styles.\n\nprop | type | description\n-----|------|------------\n`truncate` | boolean | sets overflow ellipsis and props to make it work\n\n## Background API\n\nAvailable on `<Box />` or `withBackground(Comp)`. Uses glamor.\nPane implements shorthands for this.\n\nprop | type | description\n-----|------|-------------\n`background` | ' + _Object$keys(theme.backgrounds).join(', ') + ' |  sets background-color, border-color and color\n`interactive` | bool | adds styling on hover and active\n\n'
        ),
        React.createElement(
          Box,
          { background: 'dark', clearfix: true },
          React.createElement(
            Box,
            { background: 'white', padding: majorScale(2), margin: majorScale(2) },
            'background=\'white\''
          ),
          React.createElement(
            Box,
            { background: 'tint', padding: majorScale(2), margin: majorScale(2) },
            'background=\'tint\''
          ),
          React.createElement(
            Box,
            { background: 'tint1', padding: majorScale(2), margin: majorScale(2) },
            'background=\'tint\' === background=\'tint1\''
          ),
          React.createElement(
            Box,
            { background: 'tint2', padding: majorScale(2), margin: majorScale(2) },
            'background=\'tint2\''
          )
        ),
        React.createElement(
          Content,
          { markdown: true },
          '\n\n## Background color API\n\nUses inline styles.\n\nThis is only used as an escape hatch in most cases.\n`<Pane white|tint|dark />` should be used in general.\n\nprop | type | default | description\n-----|------|---------|-------------\n`backgroundColor` | string | | background-color: x;\n\n## Transform API\n\nUses glamor.\n\nprop | type | description\n-----|------|------------\n`transform` | string | transform: x;\n\n## Clearfix API\n\nUses glamor.\n\nprop | type | description\n-----|------|------------\n`clearfix` | boolean | | applies a clearfix\n\n'
        )
      )
    );
  }).add('standalone', function () {
    return React.createElement(
      Box,
      {
        background: 'dark',
        padding: majorScale(2),
        margin: majorScale(2),
        rounded: true,
        shadow: true,
        textAlign: 'center' },
      React.createElement(
        Code,
        null,
        '<Box background=\'dark\' padding={majorScale(2)} margin={majorScale(2)} rounded shadow textAlign=\'center\' />'
      )
    );
  }).add('deprecation warning', function () {
    return React.createElement(
      'div',
      null,
      React.createElement(Box, { padding: true }),
      React.createElement(Box, { paddingLeft: 3 })
    );
  });
}