import React from 'react';
import { storiesOf } from '@storybook/react';
import { App, Pane, Body1, Text, Link, theme } from '../components';
import Content from './Content';
var majorScale = theme.majorScale;


var quickBrownFox = 'The quick brown fox jumps over the lazy dog';

export default function paneStory(module) {
  storiesOf('Pane', module).add('usage', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { white: true, padding: majorScale(10) },
        React.createElement(
          Content,
          { markdown: true },
          '\n# Pane\n\nThe Pane component is the base component to build layouts. Implements `<Box />`.\n\n* Pane is almost the same as a Box, but is opiniated for backgrounds/layouts.\n\n```\n<Pane dark padding={majorScale(2)}>\n  <Body1>' + quickBrownFox + '</Body1>\n</Pane>\n```\n\n'
        ),
        React.createElement(
          Pane,
          { dark: true, padding: majorScale(2) },
          React.createElement(
            Body1,
            null,
            quickBrownFox
          )
        ),
        React.createElement(
          Content,
          { markdown: true },
          '\n\nprop | type | description\n-----|------|------------\n`dark`    | boolean | dark background\n`white`   | boolean  | white background\n`tint` | boolean/1..2 | tinted background, tint={2} is darker\n`interactive` | boolean | adds a border color on hover and active\n\n'
        )
      )
    );
  }).add('is a clickable card', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { is: Link, href: '#', margin: majorScale(2), interactive: true, border: true, white: true, rounded: true, shadow: true, padding: majorScale(2) },
        React.createElement(
          Text,
          null,
          quickBrownFox
        )
      )
    );
  }).add('with dark background', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { dark: true, padding: majorScale(2), clearfix: true },
        React.createElement(
          Text,
          null,
          quickBrownFox
        )
      )
    );
  }).add('with tint background', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { dark: true, padding: majorScale(2) },
        React.createElement(
          Pane,
          { tint: true, margin: majorScale(2), padding: majorScale(2), clearfix: true },
          'Tint (1)'
        ),
        React.createElement(
          Pane,
          { tint: 2, margin: majorScale(2), padding: majorScale(2), clearfix: true },
          'Tint 2'
        )
      )
    );
  }).add('with white background', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { dark: true, padding: majorScale(2) },
        React.createElement(
          Pane,
          { white: true, margin: majorScale(2), padding: majorScale(2), clearfix: true },
          'White'
        )
      )
    );
  }).add('with rounded corners', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { dark: true, clearfix: true },
        React.createElement(
          Pane,
          { white: true, padding: majorScale(2), margin: majorScale(2), rounded: true },
          'Rounded (1)'
        ),
        React.createElement(
          Pane,
          { white: true, padding: majorScale(2), margin: majorScale(2), rounded: 2 },
          'Rounded 2'
        )
      )
    );
  }).add('with shadow', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        null,
        React.createElement(
          Pane,
          { white: true, padding: majorScale(2), margin: majorScale(2), rounded: true, shadow: true },
          'Shadow (1)'
        ),
        React.createElement(
          Pane,
          { white: true, padding: majorScale(2), margin: majorScale(2), rounded: true, shadow: 2 },
          'Shadow 2'
        )
      )
    );
  }).add('standalone', function () {
    return React.createElement(
      Pane,
      null,
      React.createElement(
        Pane,
        { white: true, padding: majorScale(2), margin: majorScale(2), rounded: true, shadow: true },
        'Shadow (1)'
      ),
      React.createElement(
        Pane,
        { white: true, padding: majorScale(2), margin: majorScale(2), rounded: true, shadow: 2 },
        'Shadow 2'
      )
    );
  });
}