import React from 'react';
import { storiesOf } from '@storybook/react';
import { App, Text, Code, Pane, theme, Display1, Display2, Display3, Display4, Display5, Body1, Body2, Caps1, Caps2 } from '../components';
import Content from './Content';
var majorScale = theme.majorScale;


export default function textStory(module) {
  storiesOf('Text', module).add('usage', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { white: true, padding: majorScale(10) },
        React.createElement(
          Content,
          { markdown: true },
          '\n# Text\n\nThe Text component is a `p` by default. Implements Box.\n\n## Use our predefined text components\n\n```\n<Display1>Display1</Display1>\n<Display2>Display2</Display2>\n<Display3>Display3</Display3>\n<Display4>Display4</Display4>\n<Display5>Display5</Display5>\n<Body1>Body1</Body1>\n<Body2>Body2</Body2>\n<Caps1>Caps1</Caps1>\n<Caps2>Caps2</Caps2>\n```\n\n'
        ),
        React.createElement(
          Display1,
          null,
          'Display1'
        ),
        React.createElement(
          Display2,
          null,
          'Display2'
        ),
        React.createElement(
          Display3,
          null,
          'Display3'
        ),
        React.createElement(
          Display4,
          null,
          'Display4'
        ),
        React.createElement(
          Display5,
          null,
          'Display5'
        ),
        React.createElement(
          Body1,
          null,
          'Body1'
        ),
        React.createElement(
          Body2,
          null,
          'Body2'
        ),
        React.createElement(
          Caps1,
          null,
          'Caps1'
        ),
        React.createElement(
          Caps2,
          null,
          'Caps2'
        ),
        React.createElement(
          Content,
          { markdown: true },
          '\n\n## Using the Text component directly\n\nYou can use the Text component directly, but it needs to be configured with a textColor and sometimes a different semantic element.\nBelow is essentially the same as using the components described above.\n\n```\n<Text is="h2" textColor="title" textStyle=\'display1\'>Display (1)</Text>\n<Text is="h2" textColor="title" textStyle=\'display2\'>Display 2</Text>\n<Text is="h2" textColor="title" textStyle=\'display3\'>Display 3</Text>\n<Text is="h2" textColor="title" textStyle=\'display4\'>Display 4</Text>\n<Text is="h2" textColor="title" textStyle=\'display5\'>Display 5</Text>\n<Text textColor="body" textStyle=\'body1\'>Body (1)</Text>\n<Text textColor="body" textStyle=\'body2\'>Body 2</Text>\n<Text textColor="body" textStyle=\'mono\'>Mono</Text>\n<Text textColor="body" textStyle=\'caps1\'>Caps 1</Text>\n<Text textColor="body" textStyle=\'caps2\'>Caps 2</Text>\n```\n\n'
        ),
        React.createElement(
          Text,
          { is: 'h2', textColor: 'title', textStyle: 'display1' },
          'Display (1)'
        ),
        React.createElement(
          Text,
          { is: 'h2', textColor: 'title', textStyle: 'display2' },
          'Display 2'
        ),
        React.createElement(
          Text,
          { is: 'h2', textColor: 'title', textStyle: 'display3' },
          'Display 3'
        ),
        React.createElement(
          Text,
          { is: 'h2', textColor: 'title', textStyle: 'display4' },
          'Display 4'
        ),
        React.createElement(
          Text,
          { is: 'h2', textColor: 'title', textStyle: 'display5' },
          'Display 5'
        ),
        React.createElement(
          Text,
          { textColor: 'body', textStyle: 'body1' },
          'Body (1)'
        ),
        React.createElement(
          Text,
          { textColor: 'body', textStyle: 'body2' },
          'Body 2'
        ),
        React.createElement(
          Text,
          { textColor: 'body', textStyle: 'mono' },
          'Mono'
        ),
        React.createElement(
          Text,
          { textColor: 'body', textStyle: 'caps1' },
          'Caps 1'
        ),
        React.createElement(
          Text,
          { textColor: 'body', textStyle: 'caps2' },
          'Caps 2'
        ),
        React.createElement(
          Content,
          { markdown: true },
          '\n\n## Text Styles API\n\nListed as a reference. Is not unique to `<Text />`, but is implemented on Box.\n\nprop | type | description\n-----|------|------------\n`textStyle` | display1, display2, display3, display4, body1, body2, mono, caps1, caps2 | use text style\n`textColor` | title, body, muted, white | use text color\n'
        )
      )
    );
  }).add('Truncate Text', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        'div',
        { style: { width: 240 } },
        React.createElement(
          Text,
          { textStyle: 'body1', truncate: true },
          'Truncate Text when it gets too long lorem ipsum'
        )
      )
    );
  }).add('Muted (1) Text', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Text,
        { muted: true },
        'Soft Mute your text: ',
        React.createElement(
          Code,
          null,
          '<Text muted>...</Text>'
        )
      )
    );
  }).add('Muted 2 Text', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Text,
        { muted: 2 },
        'Mute your text even more: ',
        React.createElement(
          Code,
          null,
          '<Text muted={2}>...</Text>'
        )
      )
    );
  }).add('standalone', function () {
    return React.createElement(
      Text,
      { muted: 2 },
      'Mute your text even more: ',
      React.createElement(
        Code,
        null,
        '<Text muted={2}>...</Text>'
      )
    );
  });
}