import _Object$keys from 'babel-runtime/core-js/object/keys';
import React from 'react';
import { storiesOf } from '@storybook/react';
import Color from 'color';
import { App, Pane, Display1, Display3, Text, Code, Body1, Body2, Popover, theme } from '../components';
var majorScale = theme.majorScale;

var mjs = majorScale;

var pickColor = function pickColor(color) {
  return _Object$keys(theme.rawColors).filter(function (key) {
    return key.indexOf(color) > -1;
  }).map(function (key) {
    return {
      key: key,
      val: theme.rawColors[key]
    };
  });
};

var groupedColors = {
  green: pickColor('green'),
  blue: pickColor('blue'),
  grey: pickColor('grey'),
  pink: pickColor('pink'),
  peach: pickColor('peach')
};

var ColorSwatchDetails = function ColorSwatchDetails(_ref) {
  var color = _ref.color;
  return React.createElement(
    Pane,
    { width: '160px', height: '160px', padding: mjs(2) },
    React.createElement(
      Body1,
      null,
      Color(color).hsl().round().string()
    ),
    React.createElement(
      Body1,
      null,
      Color(color).rgb().round().string()
    ),
    React.createElement(
      Body1,
      null,
      'Hue: ',
      Color(color).hsl().round().hue()
    )
  );
};

function findRawColor(color) {
  return _Object$keys(theme.rawColors).find(function (key) {
    return theme.rawColors[key] === color;
  });
}

var ColorSwatch = function ColorSwatch(_ref2) {
  var name = _ref2.name,
      color = _ref2.color,
      showRaw = _ref2.showRaw;
  return React.createElement(
    Pane,
    { style: { float: 'left' }, marginRight: mjs(2), marginBottom: mjs(2), textAlign: 'center' },
    React.createElement(
      Popover,
      { useArrow: true, content: React.createElement(ColorSwatchDetails, { color: color }) },
      React.createElement(Pane, { display: 'inline-block', circle: true, width: '64px', height: '64px', style: { backgroundColor: color } })
    ),
    React.createElement(
      Body1,
      null,
      name
    ),
    React.createElement(
      Body2,
      null,
      showRaw && findRawColor(color)
    ),
    React.createElement(
      Body2,
      { textColor: 'muted' },
      color
    )
  );
};

var Colors = function Colors(_ref3) {
  var colors = _ref3.colors,
      title = _ref3.title,
      hue = _ref3.hue;
  return React.createElement(
    Pane,
    { clearfix: true, marginBottom: mjs(4) },
    React.createElement(
      Display3,
      { marginY: mjs(2) },
      title,
      ' ',
      React.createElement(
        Text,
        { is: 'span', textColor: 'muted' },
        '\xB7 hue: ',
        hue
      )
    ),
    React.createElement(
      Pane,
      null,
      colors.map(function (obj) {
        return React.createElement(ColorSwatch, { key: obj.key, name: obj.key, color: obj.val });
      })
    )
  );
};

var TextColors = function TextColors() {
  return React.createElement(
    Pane,
    { marginBottom: majorScale(8), clearfix: true },
    React.createElement(
      Display1,
      null,
      'Text Colors'
    ),
    React.createElement(
      Body1,
      null,
      'The following colors are available as text colors. Accessible on ',
      React.createElement(
        Code,
        null,
        'theme.textColors[color]'
      ),
      '.'
    ),
    React.createElement(
      Pane,
      { marginTop: mjs(3), clearfix: true },
      _Object$keys(theme.textColors).map(function (key) {
        return React.createElement(ColorSwatch, { key: key, name: key, color: theme.textColors[key], showRaw: true });
      })
    )
  );
};

var FunctionalColors = function FunctionalColors() {
  return React.createElement(
    Pane,
    { marginBottom: majorScale(8), clearfix: true },
    React.createElement(
      Display1,
      null,
      'Functional Colors'
    ),
    React.createElement(
      Body1,
      null,
      'You should try to use functional colors instead of raw colors. Accessible on ',
      React.createElement(
        Code,
        null,
        'theme.colors[color]'
      ),
      '.'
    ),
    React.createElement(
      Pane,
      { marginTop: mjs(3), clearfix: true },
      _Object$keys(theme.colors).map(function (key) {
        return React.createElement(ColorSwatch, { key: key, name: key, color: theme.colors[key], showRaw: true });
      })
    )
  );
};

var RawColors = function RawColors() {
  return React.createElement(
    Pane,
    { marginBottom: majorScale(8), clearfix: true },
    React.createElement(
      Display1,
      null,
      'Raw Colors'
    ),
    React.createElement(
      Body1,
      null,
      'These are the underlying colors that support the functional colors. Accessible on ',
      React.createElement(
        Code,
        null,
        'theme.rawColors[color]'
      ),
      '.'
    ),
    React.createElement(Colors, { colors: groupedColors.green, title: 'Green', hue: '151' }),
    React.createElement(Colors, { colors: groupedColors.blue, title: 'Blue', hue: '209' }),
    React.createElement(Colors, { colors: groupedColors.grey, title: 'Grey', hue: '209' }),
    React.createElement(Colors, { colors: groupedColors.pink, title: 'Pink', hue: '329' }),
    React.createElement(Colors, { colors: groupedColors.peach, title: 'Peach', hue: '27' })
  );
};

export default function themeStory(module) {
  storiesOf('Design / Theme', module).add('colors', function () {
    return React.createElement(
      App,
      null,
      React.createElement(
        Pane,
        { flexAuto: true, white: true, padding: majorScale(10), clearfix: true },
        React.createElement(FunctionalColors, null),
        React.createElement(TextColors, null),
        React.createElement(RawColors, null)
      )
    );
  });
}