'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactRemarkable = require('react-remarkable');

var _reactRemarkable2 = _interopRequireDefault(_reactRemarkable);

var _glamor = require('glamor');

var _components = require('../components');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var majorScale = _components.theme.majorScale;


var contentStyles = {
  fontFamily: _components.theme.fonts.sans,
  fontSize: _components.theme.textStyles.body1.fontSize,
  fontWeight: _components.theme.textStyles.body1.fontWeight,
  letterSpacing: _components.theme.textStyles.body1.letterSpacing,
  '& > *': {
    margin: 0,
    padding: 0,
    border: 0,
    fontSize: '100%',
    font: 'inherit',
    verticalAlign: 'baseline'
  },
  '& ol, & ul': {
    listStyle: 'none'
  },
  '& blockquote, & q': {
    margin: 0,
    paddingLeft: majorScale(2),
    borderLeft: '2px solid ' + _components.theme.backgrounds.white.borderColor,
    fontStyle: 'italic',
    quotes: 'none'
  },
  '& h1': _extends({}, _components.theme.textStyles.display1, {
    color: _components.theme.textColors.title,
    marginTop: '1em',
    marginBottom: '1em'
  }),
  '& h2': _extends({}, _components.theme.textStyles.display2, {
    color: _components.theme.textColors.title,
    marginTop: '1em',
    marginBottom: '1em'
  }),
  '& h3': _extends({}, _components.theme.textStyles.display3, {
    color: _components.theme.textColors.title,
    marginTop: '1em',
    marginBottom: '1em'
  }),
  '& h4, & h5, & h6': _extends({}, _components.theme.textStyles.display4, {
    color: _components.theme.textColors.title,
    marginTop: '1em',
    marginBottom: '1em'
  }),
  '& p, & ul, & ol': _extends({}, _components.theme.textStyles.body1, {
    maxWidth: '40em',
    margin: '1em 0'
  }),
  '& ul': {
    listStyle: 'disc',
    listStylePosition: 'outside',
    marginLeft: '1.2em',
    padding: 0
  },
  '& ol': {
    listStyle: 'decimal'
  },
  '& em': {
    fontStyle: 'italic'
  },
  '& strong': {
    fontWeight: 500
  },
  '& p > code, & li > code, & table code': _extends({}, _components.theme.textStyles.body1, {
    fontFamily: _components.theme.fonts.sans,
    display: 'inline-block',
    backgroundColor: _components.theme.backgrounds.tint1.backgroundColor,
    boxShadow: 'inset 0 0 0 1px ' + _components.theme.colors.borderColor,
    padding: '0 0.5em',
    borderRadius: _components.theme.borderRadius[0],

    '&:before, &:after': {
      content: '\\00a0',
      letterSpacing: '-0.2em'
    }
  }),
  '& pre': {
    margin: '1em 0',
    overflowX: 'auto',
    textAlign: 'left',
    display: 'block',
    whiteSpace: 'pre',
    backgroundColor: _components.theme.backgrounds.tint1.backgroundColor,
    boxShadow: 'inset 0 0 0 1px ' + _components.theme.colors.borderColor,
    padding: _components.theme.minorScale(3),
    borderRadius: _components.theme.borderRadius[0]
  },
  '& pre code': _extends({}, _components.theme.textStyles.mono, {
    fontFamily: _components.theme.fonts.mono,
    padding: 0,
    background: 'none',
    '&:before, &:after': {
      content: 'none',
      letterSpacing: 0
    }
  }),
  '& hr': {
    background: _components.theme.backgrounds.tint1.backgroundColor,
    border: 0,
    height: '1px',
    margin: '32px 0'
  },
  '& table': {
    borderCollapse: 'collapse',
    borderSpacing: 0,
    width: '100%',
    margin: '1em 0'
  },
  '& thead': {
    borderBottom: '1px solid ' + _components.theme.colors.borderColor,
    backgroundColor: _components.theme.backgrounds.tint1.backgroundColor,
    position: 'relative',
    textAlign: 'left',
    padding: '0 20px',
    boxSizing: 'content-box'
  },
  '& th': {
    fontWeight: '500'
  },
  '& tbody tr': {
    borderBottom: '1px solid ' + _components.theme.colors.borderColor,
    background: _components.theme.colors.white
  },
  '& td, & th': {
    padding: '0.8em'
  }
};

var parseProps = function parseProps(_ref) {
  var children = _ref.children,
      props = _objectWithoutProperties(_ref, ['children']);

  if (typeof children === 'string') {
    return _extends({ children: _react2.default.createElement(_reactRemarkable2.default, { source: children }) }, props);
  }
  return _extends({ children: children }, props);
};

var Content = function Content(_ref2) {
  var markdown = _ref2.markdown,
      props = _objectWithoutProperties(_ref2, ['markdown']);

  return _react2.default.createElement(_components.Box, _extends({}, (0, _glamor.css)(contentStyles), parseProps(props)));
};

Content.propTypes = {
  markdown: _propTypes2.default.bool
};

Content.displayName = 'Content';

exports.default = Content;