'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = popoverStory;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _react3 = require('@storybook/react');

var _components = require('../components');

var _Content = require('./Content');

var _Content2 = _interopRequireDefault(_Content);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var majorScale = _components.theme.majorScale;


var ClosablePopoverContent = function ClosablePopoverContent(_ref) {
  var close = _ref.close;
  return _react2.default.createElement(
    _components.Pane,
    { width: '240px', height: '240px', display: 'flex', alignItems: 'center', justifyContent: 'center', flexDirection: 'column' },
    _react2.default.createElement(
      _components.Body1,
      null,
      'Hello World'
    ),
    _react2.default.createElement(
      _components.Button,
      { onClick: close },
      'Close'
    )
  );
};

var PopoverContent = function PopoverContent() {
  return _react2.default.createElement(
    _components.Pane,
    { width: '240px', height: '240px', display: 'flex', alignItems: 'center', justifyContent: 'center' },
    _react2.default.createElement(
      _components.Body1,
      null,
      'Hello World'
    )
  );
};

function popoverStory(module) {
  (0, _react3.storiesOf)('Popover', module).add('usage', function () {
    return _react2.default.createElement(
      _components.App,
      { white: true },
      _react2.default.createElement(
        _components.Pane,
        { white: true, padding: majorScale(10) },
        _react2.default.createElement(
          _Content2.default,
          { markdown: true },
          '\n# Popover\n\n**Available since v2.4.0**\n\nPopovers display floating content in relation to a target.\nPopovers appear either at the top or bottom of their target.\nThe preferred and default side is the bottom.\nPopovers use smart positioning if there is not enough space on the bottom.\n\nPopover contents are rendered in a newly created element appended to `document.body` using the `Portal` component.\n\nPopovers wrap the single child target in a `Box` element.\n\nWhen creating a popover, you must specify both:\n\n* its content, by setting the `content` prop, and\n* its target, as a single child element.\n\nWhen you pass a function to the `content` prop you will be able to close the\npopover inside of the content.\n\nPopovers close on:\n\n* outside click\n* escape key\n* window resize\n* something in content that calls the close\n\n```\nconst ClosablePopoverContent = ({ close }) =>\n  <Pane width=\'240px\' height=\'240px\' display=\'flex\' alignItems=\'center\' justifyContent=\'center\' flexDirection=\'column\'>\n    <Body1>Hello World</Body1>\n    <Button onClick={close}>Close</Button>\n  </Pane>\n\nconst PopoverContent = () =>\n  <Pane width=\'240px\' height=\'240px\' display=\'flex\' alignItems=\'center\' justifyContent=\'center\'>\n    <Body1>Hello World</Body1>\n  </Pane>\n\n<Popover content={({ close }) => <ClosablePopoverContent close={close} />} display=\'inline-block\' marginRight={majorScale(1)}>\n  <Button primary>Trigger Bottom</Button>\n</Popover>\n\n<Popover side=\'top\' content={({ close }) => <ClosablePopoverContent close={close} />} display=\'inline-block\' marginRight={majorScale(1)}>\n  <Button danger>Trigger Top</Button>\n</Popover>\n\n<Popover useSmartPositioning={false} display=\'inline-block\' content={({ close }) => <ClosablePopoverContent close={close} />}>\n  <Button paddingX=\'0\'><CogIcon /></Button>\n</Popover>\n```\n\n'
        ),
        _react2.default.createElement(
          _components.Popover,
          { content: function content(_ref2) {
              var close = _ref2.close;
              return _react2.default.createElement(ClosablePopoverContent, { close: close });
            }, display: 'inline-block', marginRight: majorScale(1) },
          _react2.default.createElement(
            _components.Button,
            { primary: true },
            'Trigger Bottom'
          )
        ),
        _react2.default.createElement(
          _components.Popover,
          { side: 'top', content: function content(_ref3) {
              var close = _ref3.close;
              return _react2.default.createElement(ClosablePopoverContent, { close: close });
            }, display: 'inline-block', marginRight: majorScale(1) },
          _react2.default.createElement(
            _components.Button,
            { danger: true },
            'Trigger Top'
          )
        ),
        _react2.default.createElement(
          _components.Popover,
          { useSmartPositioning: false, display: 'inline-block', content: function content(_ref4) {
              var close = _ref4.close;
              return _react2.default.createElement(ClosablePopoverContent, { close: close });
            } },
          _react2.default.createElement(
            _components.Button,
            { paddingX: '0' },
            _react2.default.createElement(_components.CogIcon, null)
          )
        ),
        _react2.default.createElement(
          _Content2.default,
          { markdown: true },
          '\nprop | version | type | default | description\n-----|---------|------| --------|-------------\n`children` | v2.4.0 | element.isRequired | `undefined` | the target\n`content` | v7.6.0 | (node, func).isRequired | `undefined` | content shown in Popover\n`openClass` | v2.4.0 | string | `undefined` | className added to the target\n`onOpen` | v2.4.0 | func.isRequired | `() => {}` | on open callback\n`onClose` | v2.4.0 | func.isRequired | `() => {}` | on close callback\n`side` | v2.4.0 | `bottom`, `top` | `bottom` | preferred side to show Popover\n`useSmartPositioning` | v2.4.1 | bool | `true` | toggle smart positioning\n`useArrow` | v2.4.1 | bool | `false` | don\'t use the arrow in app\n`zIndexContent` | v7.10.0 | number | `50` | z-index property of Popover content\n'
        )
      )
    );
  }).add('smart positioning', function () {
    return _react2.default.createElement(
      _components.App,
      null,
      _react2.default.createElement(
        _components.Popover,
        { useSmartPositioning: false, content: _react2.default.createElement(PopoverContent, null) },
        _react2.default.createElement(
          _components.Button,
          { position: 'absolute', primary: true },
          'Top Left'
        )
      ),
      _react2.default.createElement(
        _components.Popover,
        { useSmartPositioning: false, content: _react2.default.createElement(PopoverContent, null) },
        _react2.default.createElement(
          _components.Button,
          { position: 'absolute', top: 0, right: 0, primary: true },
          'Top Right'
        )
      ),
      _react2.default.createElement(
        _components.Popover,
        { useSmartPositioning: false, content: _react2.default.createElement(PopoverContent, null) },
        _react2.default.createElement(
          _components.Button,
          { position: 'absolute', top: 0, right: '50%', primary: true },
          'Top'
        )
      ),
      _react2.default.createElement(
        _components.Popover,
        { content: _react2.default.createElement(PopoverContent, null) },
        _react2.default.createElement(
          _components.Button,
          { position: 'absolute', top: '50%', right: '50%', primary: true },
          'Center'
        )
      ),
      _react2.default.createElement(
        _components.Popover,
        { content: _react2.default.createElement(PopoverContent, null) },
        _react2.default.createElement(
          _components.Button,
          { position: 'absolute', bottom: 0, left: 0, primary: true },
          'Bottom Left'
        )
      ),
      _react2.default.createElement(
        _components.Popover,
        { content: _react2.default.createElement(PopoverContent, null) },
        _react2.default.createElement(
          _components.Button,
          { position: 'absolute', bottom: 0, right: '50%', primary: true },
          'Bottom Center'
        )
      ),
      _react2.default.createElement(
        _components.Popover,
        { content: _react2.default.createElement(PopoverContent, null) },
        _react2.default.createElement(
          _components.Button,
          { position: 'absolute', bottom: 0, right: 0, primary: true },
          'Bottom Right'
        )
      )
    );
  }).add('position fixed', function () {
    return _react2.default.createElement(
      _components.App,
      { height: '200vh' },
      _react2.default.createElement(
        _components.Popover,
        { content: _react2.default.createElement(PopoverContent, null) },
        _react2.default.createElement(
          _components.Button,
          { position: 'fixed', bottom: 0, right: '50%', primary: true },
          'Click Me'
        )
      )
    );
  }).add('page with scrollbar', function () {
    return _react2.default.createElement(
      _components.App,
      { height: '200vh' },
      _react2.default.createElement(
        _components.Popover,
        { content: _react2.default.createElement(PopoverContent, null) },
        _react2.default.createElement(
          _components.Button,
          { position: 'absolute', bottom: 0, right: '50%', primary: true },
          'Click Me'
        )
      )
    );
  });
}